package
Version:
v0.0.0-...-cc1ad65
Opens a new window with list of versions in this module.
Published: May 2, 2025
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Stats struct {
Ports []string `json:"ports"`
DomainCount int `json:"domain_count"`
CPULoad string `json:"cpu_load"`
RAMUsage string `json:"ram_usage"`
CPUUsage string `json:"cpu_usage"`
Upload string `json:"upload"`
Download string `json:"download"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.